class text:
    black = '\x1b[30m'
    red = '\x1b[31m'
    green = '\x1b[32m'
    yellow = '\x1b[33m'
    blue = '\x1b[34m'
    magenta = '\x1b[35m'
    cyan = '\x1b[36m'
    white = '\x1b[37m'
    default = '\x1b[39m'

class background:
    black = '\x1b[39m'
    red = '\x1b[41m'
    green = '\x1b[42m'
    yellow = '\x1b[43m'
    blue = '\x1b[44m'
    magenta = '\x1b[45m'
    cyan = '\x1b[46m'
    white = '\x1b[47m'
    default = '\x1b[49m'

class formats:
    default = '\x1b[22m'
    bold = '\x1b[1m'
    dim = '\x1b[2m'
    italic = '\x1b[3m'
    underline = '\x1b[4m'
    spoiler = '\x1b[7m\x1b[8m'

default = '\x1b[0m'
